==> drd-8.x-3.0.tar.gz: drd/src/Agent/Action/V8/Base.php <==
<?php

/**
 * @file
 * Contains \Drupal\drd\Agent\Action\V8\Base.
 */

namespace Drupal\drd\Agent\Action\V8;

use Psr\Log\LogLevel;

/**
 * Base class for Remote DRD Action Code for Drupal 8.
 */
abstract class Base extends \Drupal\drd\Agent\Action\Base {
  /**
   * @inheritDoc
   */
  public static function promoteUser() {
    global $user;
    $user = \Drupal\user\Entity\User::load(1);
  }

  /**
   * @inheritDoc
   */
  public static function getCryptInstance($uuid) {
    $config = \Drupal::configFactory()->get('drd_agent.settings');
    $authorised = $config->get('authorised');
    if (empty($authorised[$uuid])) {
      return FALSE;
    }

    return \Drupal\drd\Crypt\Base::getInstance(
      $authorised[$uuid]['crypt'],
      (array) $authorised[$uuid]['cryptsetting']
    );
  }

  /**
   * @inheritDoc
   */
  public static function watchdog($message, $variables = array(), $severity = 5, $link = NULL) {
    if (self::getDebugMode()) {
      if ($link) {
        $variables['link'] = $link;
      }
      \Drupal::logger('DRD Remote')->log($severity, $message, $variables);
    }
  }

  /**
   * @inheritDoc
   */
  public static function ott($token, $config) {
    $config = \Drupal::configFactory()->getEditable('drd_agent.settings');
    $ott = $config->get('ott');
    if (!$ott) {
      self::watchdog('No OTT available', array(), LogLevel::ERROR);
      return FALSE;
    }
    $config->clear('ott');
    if (empty($ott['expires']) || $ott['expires'] < REQUEST_TIME) {
      self::watchdog('OTT expired', array(), LogLevel::ERROR);
      return FALSE;
    }
    if (empty($ott['token']) || $ott['token'] != $token) {
      self::watchdog('Token missmatch: !local / !remote', array('!local' => $ott['token'], '!remote' => $token), LogLevel::ERROR);
      return FALSE;
    }

    $service = \Drupal::service('drd_agent.setup');
    $service->run($config);
    self::watchdog('OTT config completed', array(), LogLevel::INFO);
    return TRUE;
  }

}

==> drd-8.x-3.1.tar.gz: drd/src/Agent/Action/V8/Base.php <==
<?php

/**
 * @file
 * Contains \Drupal\drd\Agent\Action\V8\Base.
 */

namespace Drupal\drd\Agent\Action\V8;

use Psr\Log\LogLevel;

/**
 * Base class for Remote DRD Action Code for Drupal 8.
 */
abstract class Base extends \Drupal\drd\Agent\Action\Base {
  /**
   * @inheritDoc
   */
  public static function promoteUser() {
    global $user;
    $user = \Drupal\user\Entity\User::load(1);
  }

  /**
   * @inheritDoc
   */
  public static function getCryptInstance($uuid) {
    $config = \Drupal::configFactory()->get('drd_agent.settings');
    $authorised = $config->get('authorised');
    if (empty($authorised[$uuid])) {
      return FALSE;
    }

    return \Drupal\drd\Crypt\Base::getInstance(
      $authorised[$uuid]['crypt'],
      (array) $authorised[$uuid]['cryptsetting']
    );
  }

  /**
   * @inheritDoc
   */
  public static function watchdog($message, $variables = array(), $severity = 5, $link = NULL) {
    if (self::getDebugMode()) {
      if ($link) {
        $variables['link'] = $link;
      }
      \Drupal::logger('DRD Remote')->log($severity, $message, $variables);
    }
  }

  /**
   * @inheritDoc
   */
  public static function ott($token, $config) {
    $config = \Drupal::configFactory()->getEditable('drd_agent.settings');
    $ott = $config->get('ott');
    if (!$ott) {
      self::watchdog('No OTT available', array(), LogLevel::ERROR);
      return FALSE;
    }
    $config->clear('ott');
    if (empty($ott['expires']) || $ott['expires'] < \Drupal::time()->getRequestTime()) {
      self::watchdog('OTT expired', array(), LogLevel::ERROR);
      return FALSE;
    }
    if (empty($ott['token']) || $ott['token'] != $token) {
      self::watchdog('Token missmatch: !local / !remote', array('!local' => $ott['token'], '!remote' => $token), LogLevel::ERROR);
      return FALSE;
    }

    $service = \Drupal::service('drd_agent.setup');
    $service->run($config);
    self::watchdog('OTT config completed', array(), LogLevel::INFO);
    return TRUE;
  }

}
